@@ -401,8 +401,8 @@ and can be one of the following "sub-properties":
 @row3col{weight, enum,
     One of "normal", "bold" or "light" (default: normal).}
 @row3col{family, enum,
-    One of "roman", "script", "decorative", "swiss", "modern" or "teletype"
-    (default: roman).}
+    One of "default", "roman", "script", "decorative", "swiss", "modern" or "teletype"
+    (default: default).}
 @row3col{underlined, @ref overview_xrcformat_type_bool,
     Whether the font should be underlined (default: 0).}
 @row3col{face, ,
@@ -519,6 +519,8 @@ from properties lists below.
     If set to 1, the control is created hidden (default: 0).}
 @row3col{tooltip, @ref overview_xrcformat_type_text,
     Tooltip to use for the control (default: not set).}
+@row3col{variant, @ref overview_xrcformat_type_string,
+    Window variant (see wxWindow::SetWindowVariant()), one of "normal", "small", "mini" or "large" (default: "normal") (new since wxWidgets 3.0.2).}
 @row3col{font, @ref overview_xrcformat_type_font,
     Font to use for the control (default: window's default).}
 @row3col{ownfont, @ref overview_xrcformat_type_font,
@@ -1700,6 +1702,32 @@ HTML markup. Note that the markup has to be escaped:
 @endcode
 
 
+@subsubsection xrc_wxsimplebook wxSimplebook
+
+wxSimplebook is similar to @ref xrc_wxnotebook "wxNotebook" but simpler: as it
+doesn't show any page headers, it doesn't use neither image list nor individual
+page bitmaps and while it still accepts page labels, they are optional as they
+are not shown to the user neither.
+
+So @c simplebookpage child elements, that must occur inside this object, only
+have the following properties:
+
+@c choicebookpage objects have the following properties:
+
+@beginTable
+@hdr3col{property, type, description}
+@row3col{label, @ref overview_xrcformat_type_text,
+     Page's label (default: empty).}
+@row3col{selected, @ref overview_xrcformat_type_bool,
+     Is the page selected initially (only one page can be selected; default: 0)?}
+@endTable
+
+As with all the other book page elements, each @c simplebookpage must have
+exactly one non-toplevel window as its child.
+
+@since 3.0.2
+
+
 @subsubsection xrc_wxslider wxSlider
 
 @beginTable
@@ -2495,7 +2523,7 @@ The subclass must satisfy a number of requirements:
 
  -# It must be derived from the class specified in @c class attribute.
  -# It must be visible in wxWidget's pseudo-RTTI mechanism, i.e. there must be
-    a DECLARE_DYNAMIC_CLASS() entry for it.
+    a wxDECLARE_DYNAMIC_CLASS() entry for it.
  -# It must support two-phase creation. In particular, this means that it has
     to have default constructor.
  -# It cannot provide custom Create() method and must be constructible using
