@@ -1,10 +1,9 @@
 ///////////////////////////////////////////////////////////////////////////////
-// Name:        animateg.cpp
+// Name:        src/generic/animateg.cpp
 // Purpose:     wxAnimation and wxAnimationCtrl
 // Author:      Julian Smart and Guillermo Rodriguez Garcia
 // Modified by: Francesco Montorsi
 // Created:     13/8/99
-// RCS-ID:      $Id$
 // Copyright:   (c) Julian Smart and Guillermo Rodriguez Garcia
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -308,7 +307,7 @@ wxAnimationCtrl::~wxAnimationCtrl()
 bool wxAnimationCtrl::LoadFile(const wxString& filename, wxAnimationType type)
 {
     wxFileInputStream fis(filename);
-    if (!fis.Ok())
+    if (!fis.IsOk())
         return false;
     return Load(fis, type);
 }
@@ -359,7 +358,7 @@ void wxAnimationCtrl::SetInactiveBitmap(const wxBitmap &bmp)
     // (which uses the bitmap's mask), our background colour would be used for
     // transparent areas - and that's not what we want (at least for
     // consistency with the GTK version)
-    if ( bmp.GetMask() != NULL && GetParent() != NULL )
+    if ( bmp.IsOk() && bmp.GetMask() != NULL && GetParent() != NULL )
         SetBackgroundColour(GetParent()->GetBackgroundColour());
 
     wxAnimationCtrlBase::SetInactiveBitmap(bmp);
@@ -504,7 +503,7 @@ void wxAnimationCtrl::IncrementalUpdateBackingStore()
 
         case wxANIM_TOPREVIOUS:
             // this disposal should never be used too often.
-            // E.g. GIF specification explicitely say to keep the usage of this
+            // E.g. GIF specification explicitly say to keep the usage of this
             //      disposal limited to the minimum.
             // In fact it may require a lot of time to restore
             if (m_currentFrame == 1)
@@ -627,7 +626,7 @@ void wxAnimationCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
 
     if ( m_backingStore.IsOk() )
     {
-        // NOTE: we draw the bitmap explicitely ignoring the mask (if any);
+        // NOTE: we draw the bitmap explicitly ignoring the mask (if any);
         //       i.e. we don't want to combine the backing store with the
         //       possibly wrong preexisting contents of the window!
         dc.DrawBitmap(m_backingStore, 0, 0, false /* no mask */);
