@@ -4,7 +4,6 @@
 // Author:      Vadim Zeitlin, Mattia Barbon
 // Modified:    Mike Wetherell
 // Created:     2004-05-16
-// RCS-ID:      $Id$
 // Copyright:   (c) 2004 Vadim Zeitlin, Mattia Barbon, 2005 M. Wetherell
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -111,7 +110,7 @@ private:
 // register in the unnamed registry so that these tests are run by default
 CPPUNIT_TEST_SUITE_REGISTRATION( HashesTestCase );
 
-// also include in it's own registry so that these tests can be run alone
+// also include in its own registry so that these tests can be run alone
 CPPUNIT_TEST_SUITE_NAMED_REGISTRATION( HashesTestCase, "HashesTestCase" );
 
 void HashesTestCase::wxHashTableTest()
@@ -378,7 +377,17 @@ void MakeKeyValuePair(size_t i, size_t count, T*& key, ValueT& value)
 
 // the test
 template <class HashMapT>
-void HashMapTest()
+void
+#ifdef __GNUC__
+// At least g++ 4.8.2 (included in Ubuntu 14.04) is known to miscompile the
+// code in this function and make all the loops below infinite when using -O2,
+// so we need to turn off optimizations for it to allow the tests to run at
+// all.
+#if __GNUC__ == 4 && __GNUC_MINOR__ == 8 && __GNUC_PATCHLEVEL__ < 3
+__attribute__((optimize("O0")))
+#endif // g++ 4.8.[012]
+#endif // g++
+HashMapTest()
 {
     typedef typename HashMapT::value_type::second_type value_type;
     typedef typename HashMapT::key_type key_type;
